﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.Diagrams.Extensions.ViewModels;
using Telerik.Windows.Diagrams.Core;

namespace DiagramMVVM
{
    public class GraphSource : SerializableGraphSourceBase<NodeViewModelBase, Link>
    {
        public override void SerializeNode(NodeViewModelBase node, SerializationInfo info)
        {
            base.SerializeNode(node, info);
            if (node.Content != null)
                info["Content"] = node.Content.ToString();
            else
                info["Content"] = string.Empty;
        }

        public override NodeViewModelBase DeserializeNode(IShape shape, Telerik.Windows.Diagrams.Core.SerializationInfo info)
        {
            NodeViewModelBase node = null;
            if (shape is IContainerShape)
            {
                node = new ContainerNode();
            }
            else
            {
                node = new Node();
            }
            if (info["Content"] != null)
                node.Content = info["Content"].ToString();
            if (info[this.NodeUniqueIdKey] != null)
            {
                var nodeUniquekey = info[this.NodeUniqueIdKey].ToString();
                this.CachedNodes[nodeUniquekey] = node;
            }

            return node;
        }

        public override void SerializeLink(Link link, SerializationInfo info)
        {
            this.ClearCache();
            base.SerializeLink(link, info);
        }

        public override string GetNodeUniqueId(NodeViewModelBase node)
        {
            if (node != null)
                return node.GetHashCode().ToString();

            return string.Empty;
        }

        public override object CreateNode(IShape shape)
        {
            var newItem = base.CreateNode(shape);
            if (shape.Content != null)
                (newItem as NodeViewModelBase).Content = shape.Content;

            return newItem;
        }
    }
}
