﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using Telerik.Windows.Controls.Diagrams;
using Telerik.Windows.Controls.Diagrams.Extensions;

namespace DiagramMVVM
{
    public partial class MainPage : UserControl
    {
        private MainViewModel model;

        static MainPage()
        {
            var saveBinding = new CommandBinding(DiagramCommands.Save, ExecuteSave, CanExecuteSave);
            var openBinding = new CommandBinding(DiagramCommands.Open, ExecuteOpen, CanExecuteOpen);

            CommandManager.RegisterClassCommandBinding(typeof(MainPage), saveBinding);
            CommandManager.RegisterClassCommandBinding(typeof(MainPage), openBinding);
        }

        public MainPage()
        {
            InitializeComponent();

            this.DataContext = this.model = new MainViewModel();
            this.toolBox.ItemsSource = new HierarchicalGalleryItemsCollection();
        }

        private static void CanExecuteSave(object sender, CanExecuteRoutedEventArgs e)
        {
            if (sender == null)
                throw new ArgumentNullException("sender");
            var owner = sender as MainPage;
            e.CanExecute = owner != null && owner.diagram != null;
        }

        private static void CanExecuteOpen(object sender, CanExecuteRoutedEventArgs e)
        {
            if (sender == null)
                throw new ArgumentNullException("sender");
            var owner = sender as MainPage;
            e.CanExecute = owner != null && owner.diagram != null;
        }

        private static void ExecuteSave(object sender, ExecutedRoutedEventArgs e)
        {
            var owner = sender as MainPage;
            if (owner != null)
            {
                var dialog = new SaveFileDialog
                {
                    DefaultExt = "xml",
                    Filter = "Diagram files|*.xml|All Files (*.*)|*.*",
                    DefaultFileName = "Diagram.xml"
                };
                if (dialog.ShowDialog() == true)
                {
                    using (var fileStream = dialog.OpenFile())
                    {
                        var serializationString = owner.diagram.Save();
                        using (var writer = new StreamWriter(fileStream))
                        {
                            writer.Write(serializationString);
                        }
                    }
                }
            }
        }

        private static void ExecuteOpen(object sender, ExecutedRoutedEventArgs e)
        {
            var owner = sender as MainPage;
            if (owner != null)
            {
                var dialog = new OpenFileDialog { Multiselect = false, Filter = "Diagram (.xml)|*.xml|All Files (*.*)|*.*" };
                if (dialog.ShowDialog() == true)
                {
                    owner.model.Source.Clear();
                    using (var fileStream = dialog.File.OpenRead())
                    {
                        var reader = new StreamReader(fileStream);
                        var serializationString = reader.ReadToEnd();
                        owner.diagram.Load(serializationString);
                    }
                }
            }
        }
    }
}
